==> uxkit-0.0.2.tgz: package/built/UXKit/UXKit.js <==
/// <reference path="./Enum.ts" />
import * as Types from "./Types";
import * as IMPView from "./View";
import * as IMPPixelLine from "./PixelLine";
import * as IMPImageView from "./ImageView";
import * as IMPControl from "./Control";
import * as IMPFont from "./Font";
import * as IMPText from "./Text";
import * as IMPLabel from "./Label";
import * as IMPButton from "./Button";
import * as IMPGestureRecognizer from "./GestureRecognizer";
import * as IMPActivityIndicatorView from "./ActivityIndicatorView";
import * as IMPSlider from "./Slider";
import * as IMPSwitch from "./Switch";
import * as IMPStepper from "./Stepper";
import * as IMPSegmentedControl from "./SegmentedControl";
import * as IMPProgressView from "./ProgressView";
import * as IMPTextField from "./TextField";
import * as IMPSearchBar from "./SearchBar";
import * as IMPPageControl from "./PageControl";
import * as IMPViewController from "./ViewController";
import * as IMPNavigationController from "./NavigationController";
import * as IMPNavigationItem from "./NavigationItem";
import * as IMPTabBarController from "./TabBarController";
import * as IMPAlertView from "./AlertView";
import * as IMPActionSheet from "./ActionSheet";
import * as IMPScrollView from "./ScrollView";
import * as IMPRefreshControl from "./RefreshControl";
import * as IMPTableView from "./TableView";
import * as IMPTableViewCell from "./TableViewCell";
import * as IMPWebView from "./WebView";
import * as IMPPageViewController from "./PageViewController";
import { ImageRenderingMode, SwipeGestureRecognizerDirection } from "./Enum";
export let PresetColor = Types.PresetColor;
// View
export class View extends IMPView.View {
    constructor(...args) {
        super(...args);
        this.origin = { x: 0, y: 0 };
        this.bounds = { width: 0, height: 0 };
    }
    static setAnimate(stateBlock, duration = 250, aniType = "timing", animationConfig = undefined, completionBlock = undefined) {
        super.setAnimate(stateBlock, duration, aniType, animationConfig, completionBlock);
    }
    static setLayout(stateBlock, duration = 250, aniType = "timing", animationConfig = undefined, completionBlock = undefined) {
        super.setLayout(stateBlock, duration, aniType, animationConfig, completionBlock);
    }
    view() { return super.view(); }
    becomeFirstResponder() { super.becomeFirstResponder(); }
    resignFirstResponder() { super.resignFirstResponder(); }
    customStyle() { return super.customStyle(); }
    layoutSubviews() { super.layoutSubviews(); }
}
export class Control extends IMPControl.Control {
    content() { return super.content(); }
    controlState() { return super.controlState(); }
    eventHandler(event, sender, touchValues) { super.eventHandler(event, sender, touchValues); }
}
export class GestureRecognizer extends IMPGestureRecognizer.GestureRecognizer {
    constructor(handler) {
        super(handler);
        this.enabled = true;
    }
    static lastTouch(values) { return super.lastTouch(values); }
}
export class TapGestureRecognizer extends IMPGestureRecognizer.TapGestureRecognizer {
    constructor(...args) {
        super(...args);
        this.maxIntervalOfTapsRequired = 350;
        this.numberOfTapsRequired = 1;
        this.numberOfTouchesRequired = 1;
    }
}
export class LongPressGestureRecognizer extends IMPGestureRecognizer.LongPressGestureRecognizer {
    constructor(...args) {
        super(...args);
        this.minimumPressDuration = 350;
        this.allowableMovement = 10;
        this.numberOfTouchesRequired = 1;
    }
}
export class PanGestureRecognizer extends IMPGestureRecognizer.PanGestureRecognizer {
}
export class SwipeGestureRecognizer extends IMPGestureRecognizer.SwipeGestureRecognizer {
    constructor(...args) {
        super(...args);
        this.direction = SwipeGestureRecognizerDirection.Right;
    }
}
// Buttons
// ImageView
export class Image extends IMPImageView.Image {
    constructor(...args) {
        super(...args);
        this.renderingMode = ImageRenderingMode.Original;
    }
    static resource(source) { return super.resource(source); }
    static remote(uri, sourceSize) { return super.remote(uri, sourceSize); }
    imageWithRenderingMode(renderingMode) { return super.imageWithRenderingMode(renderingMode); }
}
export class ImageView extends IMPImageView.ImageView {
}
// Text
export class Font extends IMPFont.Font {
    constructor(...args) {
        super(...args);
        this.pointSize = 15;
        this.fontWeight = "normal";
        this.fontStyle = "normal";
        this.familyName = undefined;
    }
    static fontWithSize(size) { return super.fontWithSize(size); }
    static boldSystemFontOfSize(size) { return super.boldSystemFontOfSize(size); }
    static italicSystemFontOfSize(size) { return super.italicSystemFontOfSize(size); }
}
export class TextParagraphStyle extends IMPText.TextParagraphStyle {
}
export class Text extends IMPText.Text {
}
export class Label extends IMPLabel.Label {
}
export class Button extends IMPButton.Button {
}
export class TextButton extends IMPButton.TextButton {
}
export class RectangleButton extends IMPButton.RectangleButton {
}
export class ActivityIndicatorView extends IMPActivityIndicatorView.ActivityIndicatorView {
}
export class Slider extends IMPSlider.Slider {
    value() { return super.value(); }
    setValue(value, animated) { super.setValue(value, animated); }
}
export class Switch extends IMPSwitch.Switch {
    isOn() { return super.isOn(); }
    setOn(on, animated) { super.setOn(on, animated); }
}
export class Stepper extends IMPStepper.Stepper {
    value() { return super.value(); }
    setValue(value) { super.setValue(value); }
}
export class SegmentedControl extends IMPSegmentedControl.SegmentedControl {
}
export class SegmentedControl_Style2 extends IMPSegmentedControl.SegmentedControl_Style2 {
}
class PixelLine extends IMPPixelLine.PixelLine {
}
export class ProgressView extends IMPProgressView.ProgressView {
    setProgress(progress, animated) { super.setProgress(progress, animated); }
}
export class TextFieldView extends IMPTextField.TextFieldView {
}
export class TextField extends IMPTextField.TextField {
    constructor(...args) {
        super(...args);
        this.text = "";
        this.editing = false;
    }
}
export class SearchBar extends IMPSearchBar.SearchBar {
}
export class PageControl extends IMPPageControl.PageControl {
}
// ViewController
export class NavigationItem extends IMPNavigationItem.NavigationItem {
}
export class ViewController extends IMPViewController.ViewController {
    static navigationItem(navigationController, canGoBack) {
        return super.navigationItem(navigationController, canGoBack);
    }
    loadView() { return super.loadView(); }
    viewDidLoad() { super.viewDidLoad(); }
    viewWillUnload() { super.viewWillUnload(); }
    viewWillAppear() { super.viewWillAppear(); }
    viewDidAppear() { super.viewDidAppear(); }
    viewWillDisappear() { super.viewWillDisappear(); }
    viewDidDisappear() { super.viewDidDisappear(); }
    navigationController() { return super.navigationController(); }
    presentViewController(ViewControllerClass, args, animated = true) { super.presentViewController(ViewController, args, animated); }
    dismissViewController(animated = true) { super.dismissViewController(animated); }
}
ViewController.title = "";
export class NavigationController extends IMPNavigationController.NavigationController {
    showViewController(ViewControllerClass, args) { super.showViewController(ViewControllerClass, args); }
    popViewController() { super.popViewController(); }
    popToRootViewController() { super.popToRootViewController(); }
}
export class TabBarController extends IMPTabBarController.TabBarController {
    constructor(...args) {
        super(...args);
        this.viewControllers = [];
        this.tabItems = [];
    }
    setSelectedIndex(selectedIndex) { super.setSelectedIndex(selectedIndex); }
}
// AlertView
export class AlertView extends IMPAlertView.AlertView {
    constructor(...args) {
        super(...args);
        this.title = "";
        this.message = "";
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
    }
    static show(inViewController, title, message, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        super.show(inViewController, title, message, buttonTitles, cancelButtonIndex, handler);
    }
}
// ActionSheet 
export class ActionSheet extends IMPActionSheet.ActionSheet {
    constructor(...args) {
        super(...args);
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
    }
    static show(inViewController, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        super.show(inViewController, buttonTitles, cancelButtonIndex, handler);
    }
}
export class ScrollView extends IMPScrollView.ScrollView {
    setContentOffset(offset, animated) { super.setContentOffset(offset, animated); }
}
// RefreshControl
export class RefreshControl extends IMPRefreshControl.RefreshControl {
}
export class TableView extends IMPTableView.TableView {
    reloadData() { super.reloadData(); }
}
export class TableViewCell extends IMPTableViewCell.TableViewCell {
    view() { return super.view(); }
    accessoryView() { return super.accessoryView(); }
    separatorView() { return super.separatorView(); }
    canPerformAction() { return super.canPerformAction(); }
    actionView() { return super.actionView(); }
    endEditing() { super.endEditing(); }
    onDelete() { super.onDelete(); }
}
export class WebView extends IMPWebView.WebView {
}
export class PageViewController extends IMPPageViewController.PageViewController {
    constructor(...args) {
        super(...args);
        this.viewControllers = [];
    }
}

==> uxkit-0.0.3.tgz: package/built/UXKit/UXKit.js <==
/// <reference path="./Enum.ts" />
import * as Types from "./Types";
import * as IMPView from "./View";
import * as IMPPixelLine from "./PixelLine";
import * as IMPImageView from "./ImageView";
import * as IMPControl from "./Control";
import * as IMPFont from "./Font";
import * as IMPText from "./Text";
import * as IMPLabel from "./Label";
import * as IMPButton from "./Button";
import * as IMPGestureRecognizer from "./GestureRecognizer";
import * as IMPActivityIndicatorView from "./ActivityIndicatorView";
import * as IMPSlider from "./Slider";
import * as IMPSwitch from "./Switch";
import * as IMPStepper from "./Stepper";
import * as IMPSegmentedControl from "./SegmentedControl";
import * as IMPProgressView from "./ProgressView";
import * as IMPTextField from "./TextField";
import * as IMPSearchBar from "./SearchBar";
import * as IMPPageControl from "./PageControl";
import * as IMPViewController from "./ViewController";
import * as IMPNavigationController from "./NavigationController";
import * as IMPNavigationBar from "./NavigationBar";
import * as IMPNavigationItem from "./NavigationItem";
import * as IMPTabBarController from "./TabBarController";
import * as IMPAlertView from "./AlertView";
import * as IMPActionSheet from "./ActionSheet";
import * as IMPScrollView from "./ScrollView";
import * as IMPRefreshControl from "./RefreshControl";
import * as IMPTableView from "./TableView";
import * as IMPTableViewCell from "./TableViewCell";
import * as IMPWebView from "./WebView";
import * as IMPPageViewController from "./PageViewController";
import * as IMPStatusBar from "./StatusBar";
import { ImageRenderingMode, SwipeGestureRecognizerDirection } from "./Enum";
export let PresetColor = Types.PresetColor;
// View
export class View extends IMPView.View {
    constructor(...args) {
        super(...args);
        this.origin = { x: 0, y: 0 };
        this.bounds = { width: 0, height: 0 };
    }
    static setAnimate(stateBlock, duration = 250, aniType = "timing", animationConfig = undefined, completionBlock = undefined) {
        super.setAnimate(stateBlock, duration, aniType, animationConfig, completionBlock);
    }
    static setLayout(stateBlock, duration = 250, aniType = "timing", animationConfig = undefined, completionBlock = undefined) {
        super.setLayout(stateBlock, duration, aniType, animationConfig, completionBlock);
    }
    view() { return super.view(); }
    becomeFirstResponder() { super.becomeFirstResponder(); }
    resignFirstResponder() { super.resignFirstResponder(); }
    customStyle() { return super.customStyle(); }
    layoutSubviews() { super.layoutSubviews(); }
}
export class Control extends IMPControl.Control {
    content() { return super.content(); }
    controlState() { return super.controlState(); }
    eventHandler(event, sender, touchValues) { super.eventHandler(event, sender, touchValues); }
}
export class GestureRecognizer extends IMPGestureRecognizer.GestureRecognizer {
    constructor(handler) {
        super(handler);
        this.enabled = true;
    }
    static lastTouch(values) { return super.lastTouch(values); }
}
export class TapGestureRecognizer extends IMPGestureRecognizer.TapGestureRecognizer {
    constructor(...args) {
        super(...args);
        this.maxIntervalOfTapsRequired = 350;
        this.numberOfTapsRequired = 1;
        this.numberOfTouchesRequired = 1;
    }
}
export class LongPressGestureRecognizer extends IMPGestureRecognizer.LongPressGestureRecognizer {
    constructor(...args) {
        super(...args);
        this.minimumPressDuration = 350;
        this.allowableMovement = 10;
        this.numberOfTouchesRequired = 1;
    }
}
export class PanGestureRecognizer extends IMPGestureRecognizer.PanGestureRecognizer {
}
export class SwipeGestureRecognizer extends IMPGestureRecognizer.SwipeGestureRecognizer {
    constructor(...args) {
        super(...args);
        this.direction = SwipeGestureRecognizerDirection.Right;
    }
}
// Buttons
// ImageView
export class Image extends IMPImageView.Image {
    constructor(...args) {
        super(...args);
        this.renderingMode = ImageRenderingMode.Original;
    }
    static resource(source) { return super.resource(source); }
    static remote(uri, sourceSize) { return super.remote(uri, sourceSize); }
    imageWithRenderingMode(renderingMode) { return super.imageWithRenderingMode(renderingMode); }
}
export class ImageView extends IMPImageView.ImageView {
}
// Text
export class Font extends IMPFont.Font {
    constructor(...args) {
        super(...args);
        this.pointSize = 15;
        this.fontWeight = "normal";
        this.fontStyle = "normal";
        this.familyName = undefined;
    }
    static fontWithSize(size) { return super.fontWithSize(size); }
    static boldSystemFontOfSize(size) { return super.boldSystemFontOfSize(size); }
    static italicSystemFontOfSize(size) { return super.italicSystemFontOfSize(size); }
}
export class TextParagraphStyle extends IMPText.TextParagraphStyle {
}
export class Text extends IMPText.Text {
}
export class Label extends IMPLabel.Label {
}
export class Button extends IMPButton.Button {
}
export class TextButton extends IMPButton.TextButton {
}
export class RectangleButton extends IMPButton.RectangleButton {
}
export class ActivityIndicatorView extends IMPActivityIndicatorView.ActivityIndicatorView {
}
export class Slider extends IMPSlider.Slider {
    value() { return super.value(); }
    setValue(value, animated) { super.setValue(value, animated); }
}
export class Switch extends IMPSwitch.Switch {
    isOn() { return super.isOn(); }
    setOn(on, animated) { super.setOn(on, animated); }
}
export class Stepper extends IMPStepper.Stepper {
    value() { return super.value(); }
    setValue(value) { super.setValue(value); }
}
export class SegmentedControl extends IMPSegmentedControl.SegmentedControl {
}
export class SegmentedControl_Style2 extends IMPSegmentedControl.SegmentedControl_Style2 {
}
class PixelLine extends IMPPixelLine.PixelLine {
}
export class ProgressView extends IMPProgressView.ProgressView {
    setProgress(progress, animated) { super.setProgress(progress, animated); }
}
export class TextFieldView extends IMPTextField.TextFieldView {
}
export class TextField extends IMPTextField.TextField {
    constructor(...args) {
        super(...args);
        this.text = "";
        this.editing = false;
    }
}
export class SearchBar extends IMPSearchBar.SearchBar {
}
export class PageControl extends IMPPageControl.PageControl {
}
// ViewController
export class NavigationItem extends IMPNavigationItem.NavigationItem {
}
export class BarButtonItem extends IMPNavigationItem.BarButtonItem {
}
export class ViewController extends IMPViewController.ViewController {
    constructor(...args) {
        super(...args);
        this.title = "";
    }
    // view configure
    loadView() { return super.loadView(); }
    loadingView() { return super.loadingView(); }
    // life cycle
    autoRelease(obj) { super.autoRelease(obj); }
    viewDidLoad() { super.viewDidLoad(); }
    viewWillUnload() { super.viewWillUnload(); }
    // modal view controller
    presentViewController(viewController, animated = true) { super.presentViewController(viewController, animated); }
    dismissViewController(animated = true) { super.dismissViewController(animated); }
    setStatusBarHidden(hidden, animated) { super.setStatusBarHidden(hidden, animated); }
}
export class ViewControllerRotationLock extends IMPViewController.ViewControllerRotationLock {
    static lock() { super.lock(); }
    static lockOrientation() { super.lockOrientation(); }
    static unlock() { super.unlock(); }
    static setInterfaceOrientation(interfaceOrientation) { super.setInterfaceOrientation(interfaceOrientation); }
}
export class NavigationBar extends IMPNavigationBar.NavigationBar {
}
export class NavigationController extends IMPNavigationController.NavigationController {
    showViewController(item, animated = true) { super.showViewController(item, animated); }
    popViewController(animated = true) { super.popViewController(animated); }
    popToRootViewController(animated = true) { super.popToRootViewController(animated); }
}
export class TabBarController extends IMPTabBarController.TabBarController {
    constructor(...args) {
        super(...args);
        this.viewControllers = [];
        this.tabItems = [];
    }
    setSelectedIndex(selectedIndex) { super.setSelectedIndex(selectedIndex); }
}
// AlertView
export class AlertView extends IMPAlertView.AlertView {
    constructor(...args) {
        super(...args);
        this.title = "";
        this.message = "";
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
    }
    static show(inViewController, title, message, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        super.show(inViewController, title, message, buttonTitles, cancelButtonIndex, handler);
    }
}
// ActionSheet 
export class ActionSheet extends IMPActionSheet.ActionSheet {
    constructor(...args) {
        super(...args);
        this.buttonTitles = [];
        this.reversedIndexes = [];
        this.dangerIndexes = [];
        this.cancelButtonIndex = -1;
    }
    static show(inViewController, buttonTitles = ["OK"], cancelButtonIndex = 0, handler) {
        super.show(inViewController, buttonTitles, cancelButtonIndex, handler);
    }
}
export class ScrollView extends IMPScrollView.ScrollView {
    setContentOffset(offset, animated) { super.setContentOffset(offset, animated); }
}
// RefreshControl
export class RefreshControl extends IMPRefreshControl.RefreshControl {
}
export class TableView extends IMPTableView.TableView {
    reloadData() { super.reloadData(); }
}
export class TableViewCell extends IMPTableViewCell.TableViewCell {
    view() { return super.view(); }
    accessoryView() { return super.accessoryView(); }
    separatorView() { return super.separatorView(); }
    canPerformAction() { return super.canPerformAction(); }
    actionView() { return super.actionView(); }
    endEditing() { super.endEditing(); }
    onDelete() { super.onDelete(); }
}
export class WebView extends IMPWebView.WebView {
}
export class PageViewController extends IMPPageViewController.PageViewController {
    constructor(...args) {
        super(...args);
        this.viewControllers = [];
    }
}
export class StatusBar extends IMPStatusBar.StatusBar {
}
